{% extends "./base.html" %}

{% block title %}Forbidden (403){% endblock %}

{% block content %}
  <h1>Forbidden (403)</h1>

  <p>CSRF verification failed. Request aborted.</p>
{% endblock content %}
