/* Styles for vue theme */

.cast-date-facet-container {
    display: flex;
    flex-wrap: wrap;
    height: auto;
}

.cast-date-facet-item {
    margin-right: 10px;
    margin-left: 10px;
}

.cast-video {
    width: 100%;
    height: 100%;
}
