{{ form.non_field_errors }}
<form method="get">
  <p>
    <label for="id_search">Search:</label>
    {{ form.search }}
  </p>
  <p>
    <label>Date:</label>
    <input type="date" name="date_after" placeholder="YYYY/MM/DD" id="id_date_0">
    -<input type="date" name="date_before" placeholder="YYYY/MM/DD" id="id_date_1">
  </p>
  <p>
    {{ form.date_facets.errors }}
    <label for="id_date_facets">Date Facets:</label>
    {{ form.date_facets }}
  </p>
  <p>
    <label for="id_o">Ordering:</label>
    <select name="o" id="id_o">
      <option value="" selected="">---------</option>
      <option value="visible_date">Date</option>
      <option value="-visible_date">Date (descending)</option>
    </select>
  </p>
  <button type="submit">Filter</button>
</form>
